[SCM] Samba Shared Repository - branch master updated

Jeremy Allison jra at samba.org
Wed Sep 18 19:47:04 CEST 2013


The branch, master has been updated
       via  887f4fb Free memory on error
       via  75f353b s3: libsmb - 10150 - Not all OEM servers support the ALTNAME info level.
      from  ff88694 Give slapd a second to startup

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -----------------------------------------------------------------
commit 887f4fbf4396489f353773de0606597c68f71b8a
Author: Alistair Leslie-Hughes <leslie_alistair at hotmail.com>
Date:   Wed Sep 4 16:50:14 2013 +1000

    Free memory on error
    
    Reviewed-by: Volker Lendecke <vl at samba.org>
    Reviewed-by: Jeremy Allison <jra at samba.org>
    
    Autobuild-User(master): Jeremy Allison <jra at samba.org>
    Autobuild-Date(master): Wed Sep 18 19:46:41 CEST 2013 on sn-devel-104

commit 75f353b857d50291672adefc6eefd210c9e8a0f7
Author: Jeremy Allison <jra at samba.org>
Date:   Tue Sep 17 18:10:16 2013 -0700

    s3: libsmb - 10150 - Not all OEM servers support the ALTNAME info level.
    
    Sigh. Some OEM servers return NT_STATUS_NOT_IMPLEMENTED not
    NT_STATUS_NOT_SUPPORTED.
    
    Signed-off-by: Jeremy Allison <jra at samba.org>
    Reviewed-by: Volker Lendecke <vl at samba.org>

-----------------------------------------------------------------------

Summary of changes:
 source3/client/client.c      |    7 ++++---
 source4/libnet/libnet_site.c |    1 +
 2 files changed, 5 insertions(+), 3 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source4/libnet/libnet_site.c b/source4/libnet/libnet_site.c
index 5a58c8a..67b8016 100644
--- a/source4/libnet/libnet_site.c
+++ b/source4/libnet/libnet_site.c
@@ -65,6 +65,7 @@ NTSTATUS libnet_FindSite(TALLOC_CTX *ctx, struct libnet_context *lctx, struct li
 	if (ret != 0) {
 		r->out.error_string = NULL;
 		status = map_nt_error_from_unix_common(errno);
+		talloc_free(tmp_ctx);
 		return status;
 	}
 


diff --git a/source3/client/client.c b/source3/client/client.c
index a348644..c3a557e 100644
--- a/source3/client/client.c
+++ b/source3/client/client.c
@@ -1710,10 +1710,11 @@ static int do_allinfo(const char *name)
 		d_printf("%s getting alt name for %s\n", nt_errstr(status),
 			 name);
 		/*
 		 * Ignore not supported, it does not hurt if we can't list
 		 * alternate names.
 		 */
-		if (NT_STATUS_EQUAL(status, NT_STATUS_NOT_SUPPORTED)) {
+		if (NT_STATUS_EQUAL(status, NT_STATUS_NOT_SUPPORTED) ||
+		    NT_STATUS_EQUAL(status, NT_STATUS_NOT_IMPLEMENTED)) {
 			altname[0] = '\0';
 		} else {
 			return false;
@@ -1710,10 +1710,11 @@ static int do_allinfo(const char *name)
 			 name);
 		/*
-		 * Ignore not supported, it does not hurt if we can't list
-		 * alternate names.
+		 * Ignore not supported or not implemented, it does not
+		 * hurt if we can't list alternate names.
 		 */
-- 
Samba Shared Repository


More information about the samba-cvs mailing list